@@ -1,4 +1,4 @@
-ExcludeVars <- c("R_SESSION_TMPDIR","R_HISTFILE")
+ExcludeVars <- c("R_SESSION_TMPDIR","R_HISTFILE","R_LIBS_USER")
 IncludeVars <- Sys.getenv()
 IncludeVars <- IncludeVars[grep("^R_",names(IncludeVars),perl=TRUE)]
 cat("const char *R_VARS[] = {\n")
