@@ -382,7 +382,8 @@ void showHelpAndExit() {
            "  -p, --verbose        Print the value of expressions to the console\n"  
            "  -l, --packages list  Load the R packages from the comma-separated 'list'\n"	
            "  -d, --datastdin      Prepend command to load 'X' as csv from stdin\n"	
-           "  -e, --eval  expr     Let R evaluate 'expr'\n"
+           "  -L, --libpath dir    Add directory to library path via '.libPaths(dir)'\n"	
+           "  -e, --eval expr      Let R evaluate 'expr'\n"
            "\n\n",
            binaryName);
     exit(-1);
@@ -390,9 +391,11 @@ void showHelpAndExit() {
 
 void showVersionAndExit() {
     char txt[64];
-    printf("%s ('%s') version %s\n\ngit revision %s as of %s\nbuilt at %s on %s\n", 
-           binaryName, programName, VERSION, 
-           gitrevision, gitdate, compiletime, compiledate);
+    printf("%s ('%s') version %s\n\ngit revision %s as of %s\n", 
+           binaryName, programName, VERSION, gitrevision, gitdate);
+#if !defined(REPRODUCIBLE_BUILD)
+    printf("built at %s on %s\n", compiletime, compiledate);
+#endif
     printf("using GNU R ");
     snprintf(txt, 63, "%d", R_SVN_REVISION);
     if (strcmp(txt, "unknown")==0) {
@@ -409,7 +412,7 @@ void showVersionAndExit() {
                    R_SVN_REVISION);
         }
     }
-    printf("\n\nCopyright (C) 2006 - 2014  Jeffrey Horner and Dirk Eddelbuettel\n"
+    printf("\n\nCopyright (C) 2006 - 2015  Jeffrey Horner and Dirk Eddelbuettel\n"
            "\n"
            "%s is free software and comes with ABSOLUTELY NO WARRANTY.\n"
            "You are welcome to redistribute it under the terms of the\n"
@@ -436,7 +439,9 @@ void showUsageAndExit() {
            "via the -e or --eval options to provide a quick R expression tester\n"
            "and calculator.\n\n"
            "More documentation is provided in the '%s' manual page and via\n"
-           "the tests directory in the sources.\n\n",
+           "the tests directory in the sources.\n\n"
+           "A number of examples are also available at\n"
+           "http://dirk.eddelbuettel.com/code/littler.examples.html.\n\n",
            binaryName, programName, binaryName, binaryName, binaryName,  
            programName, binaryName);
     exit(0);       
@@ -470,12 +475,13 @@ int main(int argc, char **argv){
     int i, nargv, c, optpos=0, vanilla=0, quick=0, interactive=0, datastdin=0;
     char *evalstr = NULL;
     char *libstr = NULL;
+    char *libpathstr = NULL;
     SEXP s_argv;
     structRstart Rst;
     char *datastdincmd = "X <- read.csv(file(\"stdin\"), stringsAsFactors=FALSE);";
 
     static struct option optargs[] = {
-        {"help",         no_argument,       NULL, 'h'}, 	/* --help also has short option -h */
+        {"help",         no_argument,       NULL, 'h'}, 
         {"usage",        no_argument,       0,    0},
         {"version",      no_argument,       NULL, 'V'},
         {"vanilla",      no_argument,       NULL, 'v'},
@@ -486,9 +492,10 @@ int main(int argc, char **argv){
         {"quick",        no_argument,       NULL, 'q'},
         {"interactive",  no_argument,       NULL, 'i'},
         {"datastdin",    no_argument,       NULL, 'd'},
+        {"libpath",      required_argument, NULL, 'L'},
         {0, 0, 0, 0}
     };
-    while ((c = getopt_long(argc, argv, "+hVve:npl:tqid", optargs, &optpos)) != -1) {
+    while ((c = getopt_long(argc, argv, "+hVve:npl:L:tqid", optargs, &optpos)) != -1) {
         switch (c) {	
         case 0:				/* numeric 0 is code for a long option */
             /* printf ("Got option %s %d", optargs[optpos].name, optpos);*/
@@ -537,6 +544,9 @@ int main(int argc, char **argv){
         case 'd':
             datastdin=1;
             break;
+        case 'L':
+            libpathstr = optarg;
+            break;
         default:
             printf("Unknown option '%c'. Try `%s --help' for help\n",(char)c, programName);
             exit(-1);
@@ -655,6 +665,14 @@ int main(int argc, char **argv){
         }
     }
 
+    if (libpathstr != NULL) {			/* if requested by user, set libPaths */
+        char buf[128];
+        membuf_t pb = init_membuf(512);
+        snprintf(buf, 127 - 12 - strlen(libpathstr), ".libPaths(\"%s\");", libpathstr); 
+        parse_eval(&pb, buf, 1);
+        destroy_membuf(pb);
+    }
+
     if (libstr != NULL) {			/* if requested by user, load libraries */
         char *ptr, *token, *strptr;
         char buf[128];
@@ -665,7 +683,7 @@ int main(int argc, char **argv){
             token = strtok_r(ptr, ",", &strptr);
             ptr = NULL; 			/* after initial call strtok expects NULL */
             if (token != NULL) {
-                snprintf(buf, 127-27-strlen(token), "suppressMessages(library(%s));", token); 
+                snprintf(buf, 127 - 27 - strlen(token), "suppressMessages(library(%s));", token); 
                 parse_eval(&pb, buf, 1);
             }
         } 
